| Title: | Provides a GUI for DAPAR |
|---|---|
| Description: | This package provides a GUI interface for the DAPAR package. The package Prostar (Proteomics statistical analysis with R) is a Bioconductor distributed R package which provides all the necessary functions to analyze quantitative data from label-free proteomics experiments. Contrarily to most other similar R packages, it is endowed with rich and user-friendly graphical interfaces, so that no programming skill is required. |
| Authors: | Thomas Burger [aut], Florence Combes [aut], Samuel Wieczorek [cre, aut], Manon Gaudin [ctb] |
| Maintainer: | Samuel Wieczorek <[email protected]> |
| License: | Artistic-2.0 |
| Version: | 1.45.0 |
| Built: | 2026-05-30 09:42:38 UTC |
| Source: | https://github.com/bioc/Prostar |
xxxx
BuildColorStyles(obj)BuildColorStyles(obj)
obj |
xx |
xxx
NULLNULL
xxxx
getDataForExprs(obj, digits = NULL)getDataForExprs(obj, digits = NULL)
obj |
xx |
digits |
xxx |
xxx
NULLNULL
Prostar
Prostar()Prostar()
A new window in the default internet browser
Samuel Wieczorek
NULLNULL